@@ -2,7 +2,7 @@ package WebService::Stripe;
 use Moo;
 with 'WebService::Client';
 
-our $VERSION = '0.1000'; # VERSION
+our $VERSION = '0.1100'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw( POST );
@@ -91,6 +91,11 @@ method refund_charge(Str $id, HashRef :$data, :$headers) {
     return $self->post( "/v1/charges/$id/refunds", $data, headers => $headers );
 }
 
+method refund_app_fee(Str $fee_id, HashRef :$data, :$headers) {
+    my $url = "/v1/application_fees/$fee_id/refunds";
+    return $self->post( $url, $data, headers => $headers );
+}
+
 method add_source(HashRef|Str $cust, HashRef $data, :$headers) {
     $cust = $cust->{id} if ref $cust;
     return $self->post( "/v1/customers/$cust/sources", $data, headers => $headers );
@@ -197,7 +202,7 @@ WebService::Stripe - Stripe API bindings
 
 =head1 VERSION
 
-version 0.1000
+version 0.1100
 
 =head1 SYNOPSIS
 
@@ -324,6 +329,13 @@ The data param is optional.
 Refunds the charge with the given id.
 The data param is optional.
 
+=head2 refund_app_fee
+
+    refund_app_fee($fee_id, data => $data)
+
+Refunds the application fee with the given id.
+The data param is optional.
+
 =head2 update_charge
 
     update_charge($id, $data)
@@ -356,7 +368,7 @@ Adds a new funding source (credit card) to an existing customer.
 
     update_account($id, data => $data)
 
-=head2 upload_identity_document( $accountID, $absPathToPhoto )
+=head2 upload_identity_document
 
 Uploads a photo ID to an account.
 
